XML tree, names, namespaces, and shared error types.
Structs
- Attribute
- XML attribute stored on an element.
- Document
- XML document represented as a typed tree backed by node IDs.
- Element
Data - Data carried by an XML element node.
- Namespace
Declaration - Namespace declaration attached to an XML element or namespace table.
- Namespace
Prefix - Prefix used to bind an XML name to a namespace URI.
- Namespace
Table - Namespace bindings available while constructing, parsing, or writing XML.
- Namespace
Uri - Namespace URI associated with a qualified XML name.
- Node
- Node stored in a document arena.
- NodeId
- Opaque identifier for a node stored in a document arena.
- QName
- Namespace-aware XML name.
- Span
- Location in a source XML document, when known.
- XmlError
- Structured error used by the XML engine.
- XmlPath
- Logical path to a node in a document tree.
Enums
- Error
Kind - High-level category for an XML engine error.
- Node
Kind - Supported XML node kinds in the core tree model.
Constants
Functions
- validate_
namespace_ binding - validate_
xml_ name - Validates the XML name subset used by this MVP.
Type Aliases
- XmlResult
- Convenient result type for core XML operations.