pub struct XmlTemplate { /* private fields */ }Expand description
Runtime output produced by xml!.
A template can be materialized as a full Document when it contains exactly
one root element, or used as a fragment when embedded as children.
Implementations
Sourceimpl XmlTemplate
impl XmlTemplate
pub fn from_fragment(fragment: FragmentBuilder) -> Self
pub fn into_fragment(self) -> FragmentBuilder
pub fn into_document(self) -> XmlResult<Document>